'use strict';

// Setup application and the modules
var app = angular.module('main', [
    'ngAnimate',
    'ui.router',
    'ngResource',
    'ngCookies',
    'ui.bootstrap',
    'luegg.directives',
    'ui.codemirror',
    'angularUtils.directives.dirPagination'
]);

// Run the application
app.run(['$rootScope', '$state', '$cookies',
    function ($rootScope, $state, $cookies) {
        $rootScope.$state = $state;
        $rootScope.activeTab;

        // Constants for the app
        $rootScope.grant_type = 'password';
        $rootScope.client_secret = 'Gh3d4HasJd';
        $rootScope.client_id = 'api';

        $rootScope.logout = function() {
            logout($cookies, $rootScope);
        };

    }
]);

// Additional directives
app.directive('ngConfirmClick', [
    function(){
        return {
            link: function (scope, element, attr) {
                var msg = attr.ngConfirmClick || "Are you sure?";
                var clickAction = attr.confirmedClick;
                element.bind('click',function (event) {
                    if ( window.confirm(msg) ) {
                        scope.$eval(clickAction)
                    }
                });
            }
        };
}])

app.directive('fileModel', ['$parse', function ($parse) {
    return {
        restrict: 'A',
        link: function(scope, element, attrs) {
            var model = $parse(attrs.fileModel);
            var modelSetter = model.assign;

            element.bind('change', function() {
                scope.$apply(function() {
                    modelSetter(scope, element[0].files[0]);
                });
            });
        }
    };
}]);

// Application configuration
app.config(
    function ($stateProvider, $urlRouterProvider) {
        $urlRouterProvider.otherwise('/admin/');

        $stateProvider
            .state('login', {
                url: '/admin/login',
                templateUrl: 'app/view/login.html',
                controller: 'LoginCtrl'
            })
            .state('accounts', {
                url: '/admin/',
                templateUrl: 'app/view/accounts.html',
                controller: 'AccountsCtrl'
            })
            .state('logs', {
                url: '/admin/logs',
                templateUrl: 'app/view/logs.html',
                controller: 'LogsCtrl'
            })
            .state('mappings', {
                url: '/admin/mappings',
                templateUrl: 'app/view/mappings.html',
                controller: 'MappingsCtrl'
            })
            .state('license', {
                url: '/admin/license',
                templateUrl: 'app/view/license.html',
                controller: 'LicenseCtrl'
            })
            .state('proxy', {
                url: '/admin/proxy',
                templateUrl: 'app/view/proxy.html',
                controller: 'ProxyCtrl'
            })
            .state('encrypt', {
                url: '/admin/encrypt',
                templateUrl: 'app/view/encrypt.html',
                controller: 'EncryptCtrl'
            })
            .state('offline', {
                url: '/admin/offline',
                templateUrl: 'app/view/offline.html',
                controller: 'OfflineCtrl'
            })
            .state('offlineInfo', {
                url: '/admin/offlineInfo',
                templateUrl: 'app/view/sub/offlineInfo.html',
                controller: 'OfflineBulkCtrl'
            })
    }
);

// Application requests to the API
app.factory('DataService', ['$http', '$cookies', '$httpParamSerializer',
    function ($http, $cookies, $httpParamSerializer) {
        return {
            getOAuth2Token: function (data) {
                return $http({
                    url: "/bumblebee/oauth/token",
                    method: "POST",
                    headers: {"Content-type": "application/x-www-form-urlencoded; charset=utf-8"},
                    data: $httpParamSerializer(data)
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            getAccounts: function () {
                return $http({
                    url: "/bumblebee/v1/api/accounts",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            getCurrentAccount: function () {
                return $http({
                    url: "/bumblebee/v1/api/accounts/current",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            updateCurrentAccount: function (id, login, email, active) {
                return $http({
                    url: "/bumblebee/v1/api/accounts/current",
                    method: "PUT",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")},
                    data: {id: id, login: login, email: email, active: active}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            addAccount: function (login, email, password, active) {
                return $http({
                    url: "/bumblebee/v1/api/accounts",
                    method: "POST",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")},
                    data: {login: login, email: email, password: password, active: active}
                })
                .catch(function (error) {
                    return error.data;
                })
            },
            updateAccount: function (id, login, email, password, active) {
                return $http({
                    url: "/bumblebee/v1/api/accounts",
                    method: "PUT",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")},
                    data: {id: id, login: login, email: email, password: password, active: active}
                })
                .catch(function (error) {
                    return error.data;
                })
            },
            deleteAccount: function (id) {
                return $http({
                    url: "/bumblebee/v1/api/accounts/" + id,
                    method: "DELETE",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                })
            },
            getMappings: function () {
                return $http({
                    url: "/bumblebee/v1/api/web/mappings",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            saveMappings: function (lines) {
                return $http({
                    url: "/bumblebee/v1/api/web/mappings",
                    method: "POST",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")},
                    data: lines
                })
                .catch(function (error) {
                    return error.data;
                })
            },
            getLogs: function () {
                return $http({
                    url: "/bumblebee/v1/api/web/logs",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            getLogsFromFile: function () {
                return $http({
                    url: "/bumblebee/v1/api/web/logs",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            downloadLogFile: function () {
                return $http({
                    url: "/bumblebee/v1/api/web/logs/download",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")},
                    responseType : 'blob'
                }).then(function(response) {
                    var url = (window.URL || window.webkitURL).createObjectURL(response.data);
                    var anchor = document.createElement("a");
                    anchor.download = "bumblebee-server.log";
                    anchor.href = url;
                    anchor.click();
                });
            },
            getLicense: function () {
                return $http({
                    url: "/bumblebee/v1/api/web/license",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            getProxySettings: function () {
                return $http({
                    url: "/bumblebee/v1/api/web/proxy",
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            encryptPassword: function (password) {
                return $http({
                    url: "/bumblebee/password?password=" +encodeURIComponent(password),
                    method: "GET"
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            saveProxy: function (host, port, user, password) {
                return $http({
                    url: "/bumblebee/v1/api/web/proxy",
                    method: "POST",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")},
                    data: {host: host, port: port, user: user, password: password}
                })
                .catch(function (error) {
                    return error.data;
                })
            },
            getOfflineRecords: function (page, size, sortBy, sortDirection) {
                return $http({
                    url: "/bumblebee/v1/api/web/offline?page="+page+"&size="+size+"&sortField="+sortBy+"&sortDirection="+sortDirection,
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            getOfflineBulkRecord: function (baseId) {
                return $http({
                    url: "/bumblebee/v1/api/web/offline/"+baseId,
                    method: "GET",
                    headers: {"Authorization": 'Bearer ' + $cookies.get("access_token")}
                })
                .catch(function (error) {
                    return error.data;
                });
            },
            getVersion: function () {
                return $http({
                    url: "/bumblebee/version",
                    method: "GET"
                })
                .catch(function (error) {
                    return error.data;
                });
            }
        }
    }
]);

app.controller('LoginCtrl', ['$rootScope', '$scope', 'DataService', '$location', '$resource', '$http', '$cookies',
  function($rootScope, $scope, DataService, $location, $resource, $http, $cookies) {
    $rootScope.activeTab = 'login';
    $scope.error = "";
    $scope.loaderShow = 0;

    $scope.data = {
        grant_type: $rootScope.grant_type,
        username: "",
        password: "",
        client_secret: $rootScope.client_secret,
        client_id: $rootScope.client_id
    };

    $scope.login = function() {
        if ($scope.data.username.length > 0 && $scope.data.password.length > 0) {
            $scope.loaderShow = 1;
            DataService.getOAuth2Token($scope.data).then(function (response) {
                $scope.loaderShow = 0;
                if (response.error) {
                    $scope.error = response.error;
                    if (response.error_description) {
                        $scope.error = response.error_description;
                    }
                } else {
                    $http.defaults.headers.common.Authorization = 'Bearer ' + response.data.access_token;
                    $cookies.put("access_token", response.data.access_token);

                    var redirect = $location.search().redirect;
                    if (redirect && redirect.length > 0) {
                        window.location.href = "/bumblebee/#!/admin/"+redirect;
                    } else {
                        window.location.href = "/bumblebee/#!/admin";
                    }
                }
            });
        }
    }
  }
]);

app.controller('AccountsCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $cookies) {
        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=accounts";
        } else {

            $rootScope.activeTab = 'accounts';
            $scope.errors = [];
            $scope.newEntryAdded = false;
            $scope.newEntryUpdated = false;
            $scope.accounts = {};
            $scope.loaderShow = 0;

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            DataService.getAccounts().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $scope.accounts = data.data;
                }
            });

            $scope.showAccountDialog = function(account) {
                showNewAccountDialog($scope, $uibModal, account);
            };

            function showNewAccountDialog($scope, $uibModal, account){
                var showNewAccountInstance = $uibModal.open({
                    animation: true,
                    templateUrl: 'app/view/dialogs/new-account.html',
                    controller : showNewAccountDialogInstanceCtrl,
                    size: 'lr',
                    resolve: {
                        item: function () {
                            return account;
                        }
                    }
                });
            }

            var showNewAccountDialogInstanceCtrl = ['$scope', '$uibModalInstance', 'item', function($scope, $uibModalInstance, item) {
                $scope.errors = [];
                $scope.newAccount = {};
                $scope.newAccount.active = true;
                console.log(item);
                if (item) {
                    $scope.newAccount = item;
                }

                $scope.addAccount = function () {
                    if ($scope.newAccount == null ||
                        $scope.newAccount.login == null ||
                        $scope.newAccount.email == null ||
                        $scope.newAccount.password == null ||
                        $scope.newAccount.active == null) {
                        $scope.errors.push('"fields": "All required fields should be filled!"');
                    } else {
                        $scope.loaderShow = 1;
                        DataService.addAccount($scope.newAccount.login, $scope.newAccount.email, $scope.newAccount.password, $scope.newAccount.active).then(function (data) {
                            $scope.loaderShow = 0;
                            if (data.error) {
                                $scope.errors = [];
                                $scope.errors.push(data.error);
                                handleApiError($cookies, data.error);
                            } else {
                                $scope.newEntryAdded = true;
                                $scope.errors = [];
                                $scope.newAccount = null;
                            }
                        });
                    }
                };

                $scope.updateAccount = function () {
                    if ($scope.newAccount == null ||
                        $scope.newAccount.id == null ||
                        $scope.newAccount.login == null ||
                        $scope.newAccount.email == null ||
                        $scope.newAccount.active == null) {
                        $scope.errors.push('"fields": "All required fields should be filled!"');
                    } else {
                        $scope.loaderShow = 1;
                        DataService.updateAccount($scope.newAccount.id, $scope.newAccount.login, $scope.newAccount.email, $scope.newAccount.password, $scope.newAccount.active).then(function (data) {
                            $scope.loaderShow = 0;
                            if (data.error) {
                                $scope.errors = [];
                                $scope.errors.push(data.error);
                                handleApiError($cookies, data.error);
                            } else {
                                $scope.newEntryUpdated = true;
                                $scope.errors = [];
                                $scope.newAccount = null;
                                location.reload();
                            }
                        });
                    }                };

                $scope.accountActiveChange = function (active) {
                    if (active) {
                        $scope.newAccount.active = false;
                    } else {
                        $scope.newAccount.active = true;
                    }
                }

                $scope.close = function () {
                    $uibModalInstance.close();
                    if ($scope.newEntryAdded || $scope.newEntryUpdated) {
                        location.reload();
                    }
                };
            }];

            $scope.updateCurrentAccount = function () {
                if ($scope.accounts.id == null ||
                    $scope.accounts.login == null ||
                    $scope.accounts.email == null) {
                    $scope.errors.push('"fields": "All required fields should be filled!"');
                } else {
                    $scope.loaderShow = 1;
                    DataService.updateCurrentAccount($scope.accounts.id, $scope.accounts.login, $scope.accounts.email, true).then(function (data) {
                        $scope.loaderShow = 0;
                        if (data.error) {
                            $scope.errors = [];
                            $scope.errors.push(data.error);
                            handleApiError($cookies, data.error);
                        } else {
                            $scope.newEntryUpdated = true;
                            $scope.errors = [];
                        }
                    });
                }
            };

            $scope.deleteAccount = function (id) {
                $scope.loaderShow = 1;
                DataService.deleteAccount(id).then(function (data) {
                    $scope.loaderShow = 0;
                    $scope.errors = [];
                    location.reload();
                });
            };
        }
    }
]);

app.controller('LogsCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$interval', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $interval, $cookies) {
        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=logs";
        } else {

            $rootScope.activeTab = 'logs';
            $scope.glued = true;
            $scope.loaderShow = 1;

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            // Get logs from file and levels count information.
            DataService.getLogs().then(function (data) {
                $scope.loaderShow = 1;
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $scope.logs = data.data;
                }
                $scope.loaderShow = 0;
            });

            $scope.loadFile = function() {
                $scope.loaderShow = 1;
                DataService.getLogsFromFile().then(function (data) {
                    if (data.error) {
                        $scope.errors.push(data.error);
                        handleApiError($cookies, data.error);
                    } else {
                        $scope.logs = data.data;
                    }
                    $scope.loaderShow = 0;
                });
            }

            $scope.downloadLogFile = function() {
                DataService.downloadLogFile();
            }
        }
    }
]);

app.controller('MappingsCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $cookies) {
        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=mappings";
        } else {

            $rootScope.activeTab = 'mappings';
            $scope.error = "";
            $scope.updated = false;
            $scope.loaderShow = 1;

            $scope.mappingContent = "";

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            DataService.getMappings().then(function (data) {
                $scope.loaderShow = 1;
                if (data.error) {
                    $scope.error = data.error;
                    handleApiError($cookies, data.error);
                } else {                    
                    $scope.mappingContent = data.data.mappings;
                }
                $scope.loaderShow = 0;
            });

            $scope.saveMappings = function(data) {
                if (!$rootScope.isUser) {
                    DataService.saveMappings($scope.mappingContent).then(function (data) {
                        if (data.message) {
                            $scope.updated = false;
                            $scope.error = data.message;
                            handleApiError($cookies, data.message);
                        } else {
                            $scope.updated = true;
                            $scope.error = "";
                            $scope.date = new Date();
                        }
                    });
                }
            }
        }
    }
]);

app.controller('LicenseCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$interval', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $interval, $cookies) {
        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=license";
        } else {

            $rootScope.redirectURL = "";
            $rootScope.activeTab = 'license';
            $scope.license = {};
            $scope.message = "";

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            $scope.loaderShow = 1;
            DataService.getLicense().then(function (data) {
                $scope.license = data.data;
                $scope.message = "";
                $scope.loaderShow = 0;
            });

            $scope.uploadLicense = function() {
                var file = $scope.uploadedfile;
                var url = "/bumblebee/v1/api/web/license";

                var data = new FormData();
                data.append('uploadfile', file);

                var config = {
                    transformRequest: angular.identity,
                    transformResponse: angular.identity,
                    headers : {
                        'Authorization': 'Bearer ' + $cookies.get("access_token"),
                        'Content-Type': undefined
                    }
                }

                $http.post(url, data, config).then(
                    // success callback
                    function(response) {
                        $scope.loaderShow = 1;
                        DataService.getLicense().then(function (data) {
                            $scope.license = data.data;
                            $scope.message = "License Updated";
                            $scope.loaderShow = 0;
                        });
                    },
                    // error callback
                    function(response) {
                        $scope.message = JSON.parse(response.data).message;
                    }
                );
            }

            $scope.updateLicense = function(licenseKey) {
                var url = "/bumblebee/v1/api/web/license-key?key=" + licenseKey;
                var config = {
                    transformRequest: angular.identity,
                    transformResponse: angular.identity,
                    headers : {
                        'Authorization': 'Bearer ' + $cookies.get("access_token"),
                        'Content-Type': undefined
                    }
                }

                $scope.loaderShow = 1;
                $http.post(url, undefined, config).then(
                    // success callback
                    function(response) {
                        DataService.getLicense().then(function (data) {
                            $scope.license = data.data;
                            $scope.message = "License Updated";
                            $scope.loaderShow = 0;
                        });
                    },
                    // error callback
                    function(response) {
                        $scope.message = JSON.parse(response.data).message;
                        $scope.loaderShow = 0;
                    }
                );
            }
        }
    }
]);

app.controller('ProxyCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $cookies) {
        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=proxy";
        } else {

            $rootScope.activeTab = 'proxy';
            $scope.error = "";
            $scope.updated = false;
            $scope.loaderShow = 1;

            $scope.proxySettings = {};

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            DataService.getProxySettings().then(function (data) {
                $scope.loaderShow = 1;
                if (data.error) {
                    $scope.error = "No settings found";
                } else {
                    $scope.proxySettings = data.data;
                }
                $scope.loaderShow = 0;
            });

            $scope.saveProxySettings = function() {
                $scope.loaderShow = 1;

                if ($scope.proxySettings.port && !$scope.isNumber($scope.proxySettings.port) ) {
                    $scope.error = "Port value should be a number!";
                } else {
                    DataService.saveProxy(
                        $scope.proxySettings.host,
                        $scope.proxySettings.port,
                        $scope.proxySettings.user,
                        $scope.proxySettings.password).then(function (data) {
                        if (data.message) {
                            $scope.updated = false;
                            $scope.error = data.message;
                        } else {
                            $scope.updated = true;
                            $scope.error = "";
                            $scope.proxySettings = data.data;
                            location.reload();
                        }
                    });
                }
            }

            $scope.isNumber= function (n) {
                return !isNaN(parseFloat(n)) && isFinite(n);
            }

            $scope.togglePassword = function () {
                $scope.typePassword = !$scope.typePassword;
            };
        }
    }
]);

app.controller('EncryptCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $cookies) {
        $rootScope.activeTab = 'encrypt';

        $scope.togglePassword = function () {
            $scope.typePassword = !$scope.typePassword;
        };

        $scope.encryptPassword = function() {
            DataService.encryptPassword($scope.password).then(function (data) {
                $scope.result = data.data.message;
            });
        }
    }
]);

app.controller('OfflineCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $cookies) {
        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=offline";
        } else {

            $rootScope.activeTab = 'offline';
            $scope.loaderShow = 1;

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            $scope.currentPage = 0;
            $scope.numPerPage = 10;
            $scope.sortDirection = "DESC";
            $scope.sortBy = "id";

            $scope.perPage = [
                {
                    "id": 1,
                    "value": "10"
                },
                {
                    "id": 2,
                    "value": "20"
                },
                {
                    "id": 3,
                    "value": "50"
                },
                {
                    "id": 4,
                    "value": "100"
                }
            ];
            $scope.changePerPage = $scope.perPage[0];

            $scope.selectPerPage = function() {
                $scope.numPerPage = angular.fromJson($scope.changePerPage).value;
            }

            DataService.getOfflineRecords($scope.currentPage, $scope.numPerPage, $scope.sortBy, $scope.sortDirection).then(function (data) {
                $scope.loaderShow = 1;
                if (data.error) {
                    $scope.errors.push(data.error);
                } else {
                    $scope.data = data.data;
                    $scope.records = $scope.data.records;
                    $scope.totalItems = $scope.data.totalElements;
                    $scope.totalPages = $scope.data.totalPages;
                }
                $scope.loaderShow = 0;
            });

            $scope.selectPage = function(page) {
                $scope.currentPage = page - 1;

                DataService.getOfflineRecords($scope.currentPage, $scope.numPerPage, $scope.sortBy, $scope.sortDirection).then(function (data) {
                    $scope.loaderShow = 1;
                    if (data.error) {
                        $scope.errors.push(data.error);
                    } else {
                        $scope.data = data.data;
                        $scope.records = $scope.data.records;
                        $scope.totalItems = $scope.data.totalElements;
                        $scope.totalPages = $scope.data.totalPages;
                    }
                    $scope.loaderShow = 0;
                });
            }

            $scope.sortByField = function(field) {
                $scope.sortBy = field;
                if ($scope.sortDirection == "DESC") {
                    $scope.sortDirection = "ASC";
                } else {
                    $scope.sortDirection = "DESC";
                }

                DataService.getOfflineRecords($scope.currentPage, $scope.numPerPage, $scope.sortBy, $scope.sortDirection).then(function (data) {
                    $scope.loaderShow = 1;
                    if (data.error) {
                        $scope.errors.push(data.error);
                    } else {
                        $scope.data = data.data;
                        $scope.records = $scope.data.records;
                        $scope.totalItems = $scope.data.totalElements;
                        $scope.totalPages = $scope.data.totalPages;
                    }
                    $scope.loaderShow = 0;
                });
            }


        }
    }
]);

app.controller('OfflineBulkCtrl', ['$rootScope', '$scope', 'DataService', '$uibModal', '$location', '$http', '$cookies',
    function ($rootScope, $scope, DataService, $uibModal, $location, $http, $cookies) {
        var baseId = $location.search().baseId;

        if (!$cookies.get("access_token")) {
            window.location.href = "/bumblebee/#!/admin/login?redirect=offlineInfo?baseId="+baseId;
        } else {

            $rootScope.activeTab = 'offlineBulk';

            if (!baseId) {
                window.location.href = "/bumblebee/#!/admin/offline";
            }

            DataService.getCurrentAccount().then(function (data) {
                if (data.error) {
                    $scope.errors.push(data.error);
                    handleApiError($cookies, data.error);
                } else {
                    $rootScope.current_account = data.data;
                    $scope.current_account = data.data;
                }
            });

            $scope.loaderShow = 1;

            DataService.getOfflineBulkRecord(baseId).then(function (data) {
                $scope.loaderShow = 1;
                if (data.error) {
                    window.location.href = "/bumblebee/#!/admin/offline";
                } else {
                    $scope.data = data.data;
                    $scope.customFields = data.data.customfields;
                }
                $scope.loaderShow = 0;
            });

            $scope.back = function () {
                window.location.href = "/bumblebee/#!/admin/offline";
            }
        }
    }
]);

app.component('version',{
    template: "ver. {{version}}",
    controller: function VersionController(DataService,$scope) {
        this.version = DataService.getVersion().then(function (data) {
            $scope.version= data.data
        });
    }
})

function handleApiError($cookies, error) {
    if (error == 'invalid_token' || error == "unauthorized") {
        $cookies.remove("access_token");
        window.location.href = "/bumblebee/#!/admin/login";
    }
}

function logout($cookies, $rootScope) {
    $cookies.remove("access_token");
    window.location.href = "/bumblebee/#!/admin/login";
    $rootScope.current_account = null;
}

function showLicensePanel(type) {
    document.getElementById('PanelLicenseMode' + (type == 'File' ? 'Key' : 'File')).style.display = 'none';
    document.getElementById('PanelLicenseMode' + type).style.display = 'block';
}
