#!/bin/bash
#Created by Sergey Oplavin on 23 May 2019
##########################################################################
#
#Startup Bumblebee for Unix
#
##########################################################################

### DEFINE CONSTANTS #######
readonly BUMBLEBEE_HOME=$(dirname $(readlink -f $0))
readonly APPLICATION_NAME=bumblebee-server
readonly DEFAULT_PORT=8080
readonly LOG_FILE_NAME=$BUMBLEBEE_HOME/daemon.log
readonly BUMBLEBEE_PID_FILE_NAME=$BUMBLEBEE_HOME/.bumblebeepid
readonly JAVA_OPTS=-Duser.dir=$BUMBLEBEE_HOME

#Set correct working directory
cd "$(dirname "$0")"

#Check -port param exist
if [ -z "$1" ]; then
port=$DEFAULT_PORT
#-port is present
elif [ "$1"=="-port" ]; then
#Check port number exist
if [ -z "$2" ]; then
echo "Please provide a port number"
exit 1
#check port is a valid integer
elif ! [[ "$2" =~ ^[1-9][0-9]+$ ]]; then
echo $2 is not a valid port number
exit 1
else 
#set port to selected user value
port=$2
fi
fi

#Check if .bumblebeepid file exist
if [ -f $BUMBLEBEE_PID_FILE_NAME ]; then
pid=$(head -n 1 $BUMBLEBEE_PID_FILE_NAME)
#check if process with PID=$pid is already runnig
if [ -e /proc/$pid -a /proc/$pid/exe ]; then
echo "Another instance is already running, pid: $(head -n 1 $BUMBLEBEE_PID_FILE_NAME)"
exit 1
else
# remove .bumblebeepid file
rm $BUMBLEBEE_PID_FILE_NAME
fi
fi

#Check if $port is free
netstat -ln | grep ":$port " 2>&1 > /dev/null 
if [ $? -eq 0 ]; then   
echo "Port $port already in use, choose another one"
exit 1
fi

#Execute jar
nohup java $JAVA_OPTS -Dserver.port=$port -jar $BUMBLEBEE_HOME/$APPLICATION_NAME.jar 0<&- &> $LOG_FILE_NAME  &
#Sign PID will empty and overwrite the file
echo $! > $BUMBLEBEE_PID_FILE_NAME

echo "****************************"
echo "Bumblebee server started on port $port"
echo "****************************"
#END